@@ -108,7 +108,7 @@ if (not $r or not $r->can("rflush")) {
 # we use a Hash to store the configuration. This is simpler to pass to functions.
 our %config;
 
-$config{version}                  = "21.05.03";  # year.month.day
+$config{version}                  = "21.08.10";  # year.month.day
 
 # search detached GPU (via vfio-pci). Only use video part, no audio.
 {
@@ -660,7 +660,7 @@ END_HTML
     $output .= "\n<p><i>NOTE: You can only login once (non persistent).</i></p>\n";
   } else {
     $output .= "\n<p><i>NOTE: You can close the browser and reconnect any time "
-      . "(within life-time). Please <b>shut down the machine properly</b></i></p>.\n";
+      . "(within life-time). Please <b>shut down the machine properly.</b></i></p>\n";
   }
 
   $output .= <<END_HTML;
@@ -673,8 +673,11 @@ END_HTML
      <li>It is not recommended to change the screen resolution, as this may freeze the display. Persistent sessions should then reconnect.</li>
     <li>We recommend that you adapt the <b>keyboard layout</b> from the <i>Preferences</i>.</li>
     <li>This is also true for any <b>login-page</b> which has a layout option in the top right corner once the session has started. </li>
+    <li>To <b>kill</b> this session, click on <form action=\"/cgi-bin/qemu-web-desktop.pl\" method=post target=_blank><input type=hidden name=session_stop value=\"$session{name}\"><input type=submit value=STOP></input></form></li>
     </ul></p>
     
+    
+    
     <hr>
     <small><a href="http://$session{server_name}/qemu-web-desktop/">Remote Desktop</a> (c) 2020 - GRADES - Synchrotron Soleil - Thanks for using our data analysis services !</small>
     </body>
